@@ -95,7 +95,8 @@ class Client:
         else:
             self.popular[fd]["count"] = str(int(self.popular[fd]["count"])+1)
 
-        
+        print(self.popular)
+        print(self.active)
 
     async def __loop(self):
         """
